# 🥦 brocc

[![PyPI - Version](https://img.shields.io/pypi/v/brocc-li.svg)](https://pypi.org/project/brocc-li)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/brocc-li.svg)](https://pypi.org/project/brocc-li)

---

[brocc.li](http://brocc.li)

```sh
# install
pipx install brocc-li
# run
brocc
```
